Learn R Programming

Planesmuestra (version 0.1)

milstd105eplans: Data: Extract the sample size and the acceptance number for MIL STD 105E acceptance sampling plans.

Description

Data for indexing sample size and acceptance number, given the code lette, AQL value and inspection type code.

Usage

data(milstd105eplans)

Arguments

Format

A data frame with 1274 entries on the following 5 variables.

Montgomery, D.C. (2005) Introduction to Statistical Quality Control, 5th ed. New York: John Wiley & Sons, ISBN 0-471-65631-3

Examples

Run this code
data(milstd105eplans)

Run the code above in your browser using DataLab